abacusai.cryptography — AbacusAI documentation

# `abacusai.cryptography`

## Module Contents

### Functions

`verify_response`(public_key, response) | Verifies an API response using the signature in the response and a public key
`get_public_key`() | Retrieves the public key of this client

abacusai.cryptography.verify_response(public_key, response)

  Verifies an API response using the signature in the response and a public key

  Raises

    ValueError – When the signature does not match or an invalid response is supplied

  Parameters

    - public_key (str) –

    - response (dict) –

abacusai.cryptography.get_public_key()

  Retrieves the public key of this client

  Returns

    The public key contents

  Return type

    str